**********************
The sherpa.plot module
**********************

.. currentmodule:: sherpa.plot

.. automodule:: sherpa.plot

   .. rubric:: Classes

   .. autosummary::
      :toctree: api

      Plot
      Contour
      Point
      Image
      Histogram
      HistogramPlot
      DataHistogramPlot
      ModelHistogramPlot
      SourceHistogramPlot
      PDFPlot
      CDFPlot
      LRHistogram
      SplitPlot
      JointPlot
      MultiPlot
      DataPlot
      TracePlot
      ScatterPlot
      PSFKernelPlot
      DataContour
      PSFKernelContour
      ModelPlot
      ComponentModelPlot
      ComponentModelHistogramPlot
      ComponentTemplateModelPlot
      SourcePlot
      ComponentSourcePlot
      ComponentSourceHistogramPlot
      ComponentTemplateSourcePlot
      PSFPlot
      ModelContour
      PSFContour
      SourceContour
      FitPlot
      FitContour
      BaseResidualPlot
      DelchiPlot
      ChisqrPlot
      RatioPlot
      ResidPlot
      BaseResidualHistogramPlot
      DelchiHistogramPlot
      ChisqrHistogramPlot
      RatioHistogramPlot
      ResidHistogramPlot
      BaseResidualContour
      ResidContour
      RatioContour
      Confidence1D
      Confidence2D
      IntervalProjection
      IntervalUncertainty
      RegionProjection
      RegionUncertainty
      TemporaryPlottingBackend

   .. rubric:: Functions

   .. autosummary::
      :toctree: api

      set_backend

Class Inheritance Diagram
=========================

.. inheritance-diagram::   Plot Contour Point Histogram HistogramPlot DataHistogramPlot ModelHistogramPlot SourceHistogramPlot PDFPlot CDFPlot LRHistogram SplitPlot JointPlot MultiPlot DataPlot TracePlot ScatterPlot PSFKernelPlot DataContour PSFKernelContour ModelPlot ComponentModelPlot ComponentModelHistogramPlot ComponentTemplateModelPlot SourcePlot ComponentSourcePlot ComponentSourceHistogramPlot ComponentTemplateSourcePlot PSFPlot ModelContour PSFContour SourceContour FitPlot FitContour BaseResidualPlot DelchiPlot ChisqrPlot RatioPlot ResidPlot BaseResidualHistogramPlot DelchiHistogramPlot ChisqrHistogramPlot RatioHistogramPlot ResidHistogramPlot BaseResidualContour ResidContour RatioContour Confidence1D Confidence2D IntervalProjectionWorker IntervalProjection IntervalUncertaintyWorker IntervalUncertainty RegionProjectionWorker RegionProjection RegionUncertaintyWorker RegionUncertainty
   :parts: 1
